Shared

Struct Shared 

pub struct Shared<S: ?Sized + IShared> { /* private fields */ }
A pointer to a shared instance from the service container.

Implementations

Source

impl<S: ?Sized + IShared> Shared<S>

pub fn new(inner: S::Pointer) -> Self

Creates a shared instance from the inner smart pointer.

pub fn into_inner(self) -> S::Pointer

Returns the inner smart pointer of the shared instance.

pub fn inner(&self) -> &S::Pointer

Returns a reference to the inner smart pointer.

pub fn inner_mut(&mut self) -> &mut S::Pointer

Returns a reference to the inner smart pointer.

pub fn is(&self, other: &Self) -> bool

Returns true if two shared instances point to the same instance.

Only compares the pointers, not the contents of the shared instances, and is therefore always cheap.

pub fn access<U, F>(&self, f: F) -> U
where S::Pointer: IAccess, F: FnOnce(Poisoning<&<S::Pointer as IAccess>::Target>) -> U,

Get access to the shared instance through a closure.

pub fn try_access<U, F>(&self, f: F) -> Option<U>
where S::Pointer: IAccess, F: FnOnce(Poisoning<&<S::Pointer as IAccess>::Target>) -> U,

Get access to the shared instance through a closure.

pub fn access_mut<U, F>(&self, f: F) -> U
where S::Pointer: IAccessMut, F: FnOnce(Poisoning<&mut <S::Pointer as IAccess>::Target>) -> U,

Get access to the shared instance through a closure.

pub fn try_access_mut<U, F>(&self, f: F) -> Option<U>
where S::Pointer: IAccessMut, F: FnOnce(Poisoning<&mut <S::Pointer as IAccess>::Target>) -> U,

Get access to the shared instance through a closure.