pub struct Shared<S: ?Sized + IShared> { /* private fields */ }Expand description
A pointer to a shared instance from the service container.
Implementations
Sourcepub fn into_inner(self) -> S::Pointer
pub fn into_inner(self) -> S::Pointer
Returns the inner smart pointer of the shared instance.
Sourcepub fn is(&self, other: &Self) -> bool
pub fn is(&self, other: &Self) -> bool
Returns true if two shared instances point to the same instance.
Only compares the pointers, not the contents of the shared instances, and is therefore always cheap.
Sourcepub fn try_access<U, F>(&self, f: F) -> Option<U>
pub fn try_access<U, F>(&self, f: F) -> Option<U>
Get access to the shared instance through a closure.
Sourcepub fn access_mut<U, F>(&self, f: F) -> U
pub fn access_mut<U, F>(&self, f: F) -> U
Get access to the shared instance through a closure.
Sourcepub fn try_access_mut<U, F>(&self, f: F) -> Option<U>
pub fn try_access_mut<U, F>(&self, f: F) -> Option<U>
Get access to the shared instance through a closure.